# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

if [ "x$CASSANDRA_HOME" = "x" ]; then
    CASSANDRA_HOME="`dirname "$0"`/.."
fi
if [ "x$CASSANDRA_LOG_DIR" = "x" ]; then
    CASSANDRA_LOG_DIR="$CASSANDRA_HOME/logs"
fi

# The directory where Cassandra's configs live (required)
if [ "x$CASSANDRA_CONF" = "x" ]; then
    CASSANDRA_CONF="$CASSANDRA_HOME/conf"
fi

# Construct jar folders to use
CASSANDRA_JARS="$CASSANDRA_HOME"/lib
DSE_JARS="$CASSANDRA_HOME"/../../lib
SLF4J_JARS="$CASSANDRA_HOME"/../dse/lib
TOOLS_JARS=

# Customization for package installs. This keeps this script compatible
# with the old style directory strucure.
if [ -d /etc/dse/cassandra ]; then
    CASSANDRA_CONF=/etc/dse/cassandra
    CASSANDRA_JARS=/usr/share/dse/common
    DSE_JARS=/usr/share/dse
    SLF4J_JARS=
fi

# Add tools jars if we are inside the tools directory
if [ -d "../../tools" ]; then
    TOOLS_JARS="../lib"
fi

# the default location for commitlogs, sstables, and saved caches
# if not set in cassandra.yaml
cassandra_storagedir="$CASSANDRA_HOME/data"

# JAVA_HOME can optionally be set here
#JAVA_HOME=/usr/local/jdk8

# The java classpath (required)
CLASSPATH="$CLASSPATH:$CASSANDRA_CONF"
for jar in "$CASSANDRA_HOME/build/"dse-db-*.jar "$CASSANDRA_JARS"/*.jar "$DSE_JARS"/dse*.jar; do
    CLASSPATH="$CLASSPATH:$jar"
done

# set JVM javaagent opts to avoid warnings/errors
if [ -z "$DSE_TOOL" ]; then
    JAVA_AGENT="$JAVA_AGENT -javaagent:$CASSANDRA_HOME/lib/jamm-0.3.3.jar"
fi

# Added sigar-bin to the java.library.path CASSANDRA-7838
JAVA_OPTS="$JAVA_OPTS:-Djava.library.path=$CASSANDRA_HOME/lib/sigar-bin"


#
# Java executable and per-Java version JVM settings
#

. "$CASSANDRA_CONF/jvm-dependent.sh"
